==> owncloud-4.0.4.tgz: owncloud/settings/l10n/hr.php <==
<?php $TRANSLATIONS = array(
"OpenID Changed" => "OpenID promijenjen",
"Invalid request" => "Neispravan zahtjev",
"Language changed" => "Jezik promijenjen",
"__language_name__" => "__ime_jezika__",
"Log" => "dnevnik",
"More" => "više",
"Add your App" => "Dodajte vašu aplikaciju",
"Select an App" => "Odaberite Aplikaciju",
"-licensed" => "-licencirano",
"by" => "od",
"Documentation" => "dokumentacija",
"Managing Big Files" => "Upravljanje velikih datoteka",
"Ask a question" => "Postavite pitanje",
"Problems connecting to help database." => "Problem pri spajanju na bazu podataka pomoći",
"Go there manually." => "Idite tamo ručno.",
"Answer" => "Odgovor",
"You use" => "Koristite",
"of the available" => "od dostupno",
"Desktop and Mobile Syncing Clients" => "Desktop i Mobile sinkronizaciji klijenti",
"Download" => "preuzimanje",
"Your password got changed" => "Vaša lozinka je promijenjena",
"Unable to change your password" => "Nemoguće promijeniti lozinku",
"Current password" => "Trenutna lozinka",
"New password" => "Nova lozinka",
"show" => "prikaz",
"Change password" => "Izmjena lozinke",
"Email" => "e-mail adresa",
"Your email address" => "Vaša e-mail adresa",
"Fill in an email address to enable password recovery" => "Ispunite vase e-mail adresa kako bi se omogućilo oporavak lozinke",
"Language" => "Jezik",
"Help translate" => "Pomoć prevesti",
"use this address to connect to your ownCloud in your file manager" => "koristite ovu adresu za spajanje na Cloud u vašem upravitelju datoteka",
"Name" => "Ime",
"Password" => "Lozinka",
"Groups" => "Grupe",
"Create" => "Izradi",
"Default Quota" => "standardni kvota",
"Other" => "ostali",
"Quota" => "kvota",
"Delete" => "Obriši"
);

==> owncloud-4.5.7.tgz: owncloud/settings/l10n/hr.php <==
<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "Nemogićnost učitavanja liste sa Apps Stora",
"Authentication error" => "Greška kod autorizacije",
"Email saved" => "Email spremljen",
"Invalid email" => "Neispravan email",
"OpenID Changed" => "OpenID promijenjen",
"Invalid request" => "Neispravan zahtjev",
"Language changed" => "Jezik promijenjen",
"Disable" => "Isključi",
"Enable" => "Uključi",
"Saving..." => "Spremanje...",
"__language_name__" => "__ime_jezika__",
"Cron" => "Cron",
"Log" => "dnevnik",
"More" => "više",
"Add your App" => "Dodajte vašu aplikaciju",
"Select an App" => "Odaberite Aplikaciju",
"See application page at apps.owncloud.com" => "Pogledajte stranicu s aplikacijama na apps.owncloud.com",
"Documentation" => "dokumentacija",
"Managing Big Files" => "Upravljanje velikih datoteka",
"Ask a question" => "Postavite pitanje",
"Problems connecting to help database." => "Problem pri spajanju na bazu podataka pomoći",
"Go there manually." => "Idite tamo ručno.",
"Answer" => "Odgovor",
"Desktop and Mobile Syncing Clients" => "Desktop i Mobile sinkronizaciji klijenti",
"Download" => "preuzimanje",
"Unable to change your password" => "Nemoguće promijeniti lozinku",
"Current password" => "Trenutna lozinka",
"New password" => "Nova lozinka",
"show" => "prikaz",
"Change password" => "Izmjena lozinke",
"Email" => "e-mail adresa",
"Your email address" => "Vaša e-mail adresa",
"Fill in an email address to enable password recovery" => "Ispunite vase e-mail adresa kako bi se omogućilo oporavak lozinke",
"Language" => "Jezik",
"Help translate" => "Pomoć prevesti",
"use this address to connect to your ownCloud in your file manager" => "koristite ovu adresu za spajanje na Cloud u vašem upravitelju datoteka",
"Name" => "Ime",
"Password" => "Lozinka",
"Groups" => "Grupe",
"Create" => "Izradi",
"Default Quota" => "standardni kvota",
"Other" => "ostali",
"Group Admin" => "Grupa Admin",
"Quota" => "kvota",
"Delete" => "Obriši"
);
